from django.shortcuts import render, redirect, get_object_or_404
from .models import Score
from users.models import Person
from management.models import CourseRegistration, Course, Programme, Spreadsheet
from .forms import ScoreForm
from django.core.paginator import Paginator
from .filters import ScoreFilter, ScoreFilterUndergrad, ScoreFilterHoD, ScoreFilterDean, ScoreFilterVC
from django.contrib.auth.decorators import login_required, permission_required
from django.contrib import messages
from django.db.models import Sum, Q
# from django.core.mail import send_mail

@login_required
def addCarry(request):
    form = ScoreForm()
    if request.method=='POST':
        form = ScoreForm(request.POST or None)
        if form.is_valid():
            form.save(commit=False).poster = request.user
            form.save(commit=False).static_lecturer = request.user
            form.save()
            # session = form.cleaned_data.get('session')
            semester = form.cleaned_data.get('semester')
            course = form.cleaned_data.get('course')
            undergrad = form.cleaned_data.get('undergrad')

            reg = Score.objects.filter(~Q(recorded="Y"), static_lecturer=request.user)[0]
            reg.session = semester.session
            reg.static_level = str(undergrad.level)
            reg.static_adviser = undergrad.programme.department.adviser
            reg.static_dean = undergrad.programme.department.faculty.dean
            reg.static_undergrad_image = undergrad.photograph
            if reg.ca1 != None and reg.exam != None:
                total = reg.ca1 + reg.exam
                reg.total = total
                reg.credit_unit = course.credit_unit
            else:
                reg.total = None
                reg.credit_unit = 0
            try:
                if total >= 70:
                    points = course.credit_unit * 5
                    reg.points = points
                elif total >= 60:
                    points = course.credit_unit * 4
                    reg.points = points
                elif total >= 50:
                    points = course.credit_unit * 3
                    reg.points = points
                elif total >= 45:
                    points = course.credit_unit * 2
                    reg.points = points
                elif total >= 40:
                    points = course.credit_unit * 1
                    reg.points = points
                elif total >= 0:
                    points = course.credit_unit * 0
                    reg.points = points
            except:
                reg.points = 0

            reg.save()

            reg95 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)
            reg91 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)

            try:
                reg97 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad).aggregate(Sum('points'))['points__sum']
                reg96 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
                for each in reg95:
                    each.semester_points = reg97
                    each.semester_credits = reg96
                    each.save()
            except:
                pass
            try:
                reg94 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('points'))['points__sum']
                reg93 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
                for each in reg91:
                    each.total_points = reg94
                    each.total_credits = reg93
                    each.save()
            except:
                pass

            reg10 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)[0]
            semester_gpa = reg10.semester_points/reg10.semester_credits
            cumulative_gpa = reg10.total_points/reg10.total_credits

            reg11 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)
            reg12 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)

            for each2 in reg11:
                each2.semester_gpa = semester_gpa
                each2.save()
            for each2 in reg12:
                each2.cumulative_gpa = cumulative_gpa
                each2.save()

            programme = undergrad.programme
            level = undergrad.level
            programme_students = Person.objects.filter(~Q(username=undergrad.username), programme=programme, level=level)

            for each3 in programme_students:
                new_entry = Score()
                new_entry.session = semester.session
                new_entry.semester = semester
                new_entry.course = course
                new_entry.poster = request.user
                new_entry.static_lecturer = request.user
                new_entry.undergrad = each3
                new_entry.total = None
                new_entry.recorded = "Y"
                new_entry.static_level = str(level)
                new_entry.save()
        messages.success(request, "Scores have been uploaded for " +str(course.course_code)+ " for the semester")
    else:
        messages.error(request, "Please review form input fields below")

    return render(request, 'result/carry.html', {'form': form})

# @login_required
# def addScore(request):
#     form = ScoreForm()
#     if request.method=='POST':
#         form = ScoreForm(request.POST or None)
#         if form.is_valid():
#             form.save(commit=False).poster = request.user
#             form.save(commit=False).static_lecturer = request.user
#             form.save()
#             session = form.cleaned_data.get('session')
#             semester = form.cleaned_data.get('semester')
#             course = form.cleaned_data.get('course')
#             undergrad = form.cleaned_data.get('undergrad')
#
#             reg = Score.objects.filter(~Q(recorded="Y"), static_lecturer=request.user)[0]
#             reg.static_adviser = undergrad.programme.department.adviser
#             reg.static_dean = undergrad.programme.department.faculty.dean
#             reg.static_undergrad_image = undergrad.photograph
#             if reg.ca1 != None and reg.exam != None:
#                 total = reg.ca1 + reg.exam
#                 reg.total = total
#                 reg.credit_unit = course.credit_unit
#             else:
#                 reg.total = None
#                 reg.credit_unit = 0
#             try:
#                 if total >= 70:
#                     points = course.credit_unit * 5
#                     reg.points = points
#                 elif total >= 60:
#                     points = course.credit_unit * 4
#                     reg.points = points
#                 elif total >= 50:
#                     points = course.credit_unit * 3
#                     reg.points = points
#                 elif total >= 45:
#                     points = course.credit_unit * 2
#                     reg.points = points
#                 elif total >= 40:
#                     points = course.credit_unit * 1
#                     reg.points = points
#                 elif total >= 0:
#                     points = course.credit_unit * 0
#                     reg.points = points
#             except:
#                 reg.points = 0
#
#             reg.save()
#
#             reg95 = Score.objects.filter(~Q(recorded="Y"), session=session, semester=semester, undergrad=undergrad)
#             reg91 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)
#
#             try:
#                 reg97 = Score.objects.filter(~Q(recorded="Y"), session=session, semester=semester, undergrad=undergrad).aggregate(Sum('points'))['points__sum']
#                 reg96 = Score.objects.filter(~Q(recorded="Y"), session=session, semester=semester, undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
#                 for each in reg95:
#                     each.semester_points = reg97
#                     each.semester_credits = reg96
#                     each.save()
#             except:
#                 pass
#             try:
#                 reg94 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('points'))['points__sum']
#                 reg93 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
#                 for each in reg91:
#                     each.total_points = reg94
#                     each.total_credits = reg93
#                     each.save()
#             except:
#                 pass
#
#             reg10 = Score.objects.filter(~Q(recorded="Y"), session=session, semester=semester, undergrad=undergrad)[0]
#             semester_gpa = reg10.semester_points/reg10.semester_credits
#             cumulative_gpa = reg10.total_points/reg10.total_credits
#
#             reg11 = Score.objects.filter(~Q(recorded="Y"), session=session, semester=semester, undergrad=undergrad)
#             reg12 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)
#
#             for each2 in reg11:
#                 each2.semester_gpa = semester_gpa
#
#                 each2.save()
#             for each2 in reg12:
#                 each2.cumulative_gpa = cumulative_gpa
#                 each2.save()
#
#         messages.success(request, "Scores have been uploaded for " +str(course.course_code)+ " for the semester")
#     else:
#         messages.error(request, "Please review form input fields below")
#
#     return render(request, 'result/score.html', {'form': form})

@login_required
def addScore(request):
    form = ScoreForm()
    if request.method=='POST':
        form = ScoreForm(request.POST or None)
        if form.is_valid():
            form.save(commit=False).poster = request.user
            form.save(commit=False).static_lecturer = request.user
            form.save()
            # session = form.cleaned_data.get('session')
            semester = form.cleaned_data.get('semester')
            course = form.cleaned_data.get('course')
            undergrad = form.cleaned_data.get('undergrad')

            reg = Score.objects.filter(~Q(recorded="Y"), static_lecturer=request.user)[0]
            reg.session = reg.semester.session
            reg.static_adviser = undergrad.programme.department.adviser
            reg.static_dean = undergrad.programme.department.faculty.dean
            reg.static_undergrad_image = undergrad.photograph
            if reg.ca1 != None and reg.exam != None:
                total = reg.ca1 + reg.exam
                reg.total = total
                reg.credit_unit = course.credit_unit
            else:
                reg.total = None
                reg.credit_unit = 0
            try:
                if total >= 70:
                    points = course.credit_unit * 5
                    reg.points = points
                elif total >= 60:
                    points = course.credit_unit * 4
                    reg.points = points
                elif total >= 50:
                    points = course.credit_unit * 3
                    reg.points = points
                elif total >= 45:
                    points = course.credit_unit * 2
                    reg.points = points
                elif total >= 40:
                    points = course.credit_unit * 1
                    reg.points = points
                elif total >= 0:
                    points = course.credit_unit * 0
                    reg.points = points
            except:
                reg.points = 0

            reg.save()

            reg95 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)
            reg91 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)

            try:
                reg97 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad).aggregate(Sum('points'))['points__sum']
                reg96 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
                for each in reg95:
                    each.semester_points = reg97
                    each.semester_credits = reg96
                    each.save()
            except:
                pass
            try:
                reg94 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('points'))['points__sum']
                reg93 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad).aggregate(Sum('credit_unit'))['credit_unit__sum']
                for each in reg91:
                    each.total_points = reg94
                    each.total_credits = reg93
                    each.save()
            except:
                pass

            reg10 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)[0]
            semester_gpa = reg10.semester_points/reg10.semester_credits
            cumulative_gpa = reg10.total_points/reg10.total_credits

            reg11 = Score.objects.filter(~Q(recorded="Y"), semester=semester, undergrad=undergrad)
            reg12 = Score.objects.filter(~Q(recorded="Y"), undergrad=undergrad)

            for each2 in reg11:
                each2.semester_gpa = semester_gpa

                each2.save()
            for each2 in reg12:
                each2.cumulative_gpa = cumulative_gpa
                each2.save()

        messages.success(request, "Scores have been uploaded for " +str(course.course_code)+ " for the semester")
    else:
        messages.error(request, "Please review form input fields below")

    return render(request, 'result/score.html', {'form': form})

@login_required
def showAcademicScores(request):
    if request.user.type == "Academic Staff":
        context = {}
        filtered_scores = ScoreFilter(
            request.GET,
            queryset = Score.objects.filter(~Q(recorded="Y"), static_lecturer=request.user).order_by('-semester__created', 'course__course_code', 'undergrad__username')
        )
        context['filtered_scores'] = filtered_scores
        paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
        page_number = request.GET.get('page')
        scores_page_obj = paginated_filtered_scores.get_page(page_number)
        context['scores_page_obj'] = scores_page_obj
        total_scores = filtered_scores.qs.count()
        context['total_scores'] = total_scores
        return render(request, 'result/all_academic_scores.html', context=context)
    else:
        return redirect('index')

@login_required
def showScoresHoD(request):
    if request.user.type == "HoD":
        context = {}
        filtered_scores = ScoreFilterHoD(
            request.GET,
            queryset = Score.objects.filter(~Q(recorded="Y"), undergrad__programme__department__hod=request.user).order_by('-semester__created', 'course__course_code', 'undergrad__username'),
            request=request,
        )
        context['filtered_scores'] = filtered_scores
        paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
        page_number = request.GET.get('page')
        scores_page_obj = paginated_filtered_scores.get_page(page_number)
        context['scores_page_obj'] = scores_page_obj
        total_scores = filtered_scores.qs.count()
        context['total_scores'] = total_scores
        return render(request, 'result/hod_scores.html', context=context)
    else:
        return redirect('index')

@login_required
def showScoresDean(request):
    if request.user.type == "Dean":
        context = {}
        filtered_scores = ScoreFilterDean(
            request.GET,
            queryset = Score.objects.filter(~Q(recorded="Y"), undergrad__programme__department__faculty__the_dean=request.user).order_by('-semester__created', 'course__course_code', 'undergrad__username'),
            request=request,
        )
        context['filtered_scores'] = filtered_scores
        paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
        page_number = request.GET.get('page')
        scores_page_obj = paginated_filtered_scores.get_page(page_number)
        context['scores_page_obj'] = scores_page_obj
        total_scores = filtered_scores.qs.count()
        context['total_scores'] = total_scores
        return render(request, 'result/dean_scores.html', context=context)
    else:
        return redirect('index')

@login_required
def showScoresVC(request):
    if request.user.type == "VC":
        context = {}
        filtered_scores = ScoreFilterVC(
            request.GET,
            queryset = Score.objects.filter(~Q(recorded="Y")).order_by('-semester__created', 'course__course_code', 'undergrad__username')
        )
        context['filtered_scores'] = filtered_scores
        paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
        page_number = request.GET.get('page')
        scores_page_obj = paginated_filtered_scores.get_page(page_number)
        context['scores_page_obj'] = scores_page_obj
        total_scores = filtered_scores.qs.count()
        context['total_scores'] = total_scores
        return render(request, 'result/vc_scores.html', context=context)
    else:
        return redirect('index')

@login_required
def showUndergradScores100Harm(request):
    context = {}
    filtered_scores = ScoreFilterUndergrad(
        request.GET,
        # queryset = Score.objects.filter(~Q(recorded="Y"), ~Q(total=None), undergrad=request.user, static_level="100").order_by('semester__semester')
        queryset = Score.objects.filter(~Q(recorded="Y"), undergrad=request.user, static_level="100").order_by('semester__semester')
    )
    context['filtered_scores'] = filtered_scores
    paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
    page_number = request.GET.get('page')
    scores_page_obj = paginated_filtered_scores.get_page(page_number)
    context['scores_page_obj'] = scores_page_obj
    total_scores = filtered_scores.qs.count()
    context['total_scores'] = total_scores
    context['payment_1h'] = request.user.h100
    context['payment_1r'] = request.user.r100
    context['payment_2h'] = request.user.h200
    return render(request, 'result/undergrad_scores_100_harm.html', context=context)

@login_required
def showUndergradScores200(request):
    context = {}
    filtered_scores = ScoreFilterUndergrad(
        request.GET,
        queryset = Score.objects.filter(~Q(recorded="Y"), undergrad=request.user, static_level="200").order_by('semester__semester')
    )
    context['filtered_scores'] = filtered_scores
    paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
    page_number = request.GET.get('page')
    scores_page_obj = paginated_filtered_scores.get_page(page_number)
    context['scores_page_obj'] = scores_page_obj
    total_scores = filtered_scores.qs.count()
    context['total_scores'] = total_scores
    context['payment_1h'] = request.user.h100
    context['payment_1r'] = request.user.r100
    context['payment_2h'] = request.user.h200
    context['payment_2r'] = request.user.r200
    context['payment_3h'] = request.user.h300
    return render(request, 'result/undergrad_scores_200.html', context=context)

@login_required
def showUndergradScores300(request):
    context = {}
    filtered_scores = ScoreFilterUndergrad(
        request.GET,
        queryset = Score.objects.filter(~Q(recorded="Y"), undergrad=request.user, static_level="300").order_by('semester__semester')
    )
    context['filtered_scores'] = filtered_scores
    paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
    page_number = request.GET.get('page')
    scores_page_obj = paginated_filtered_scores.get_page(page_number)
    context['scores_page_obj'] = scores_page_obj
    total_scores = filtered_scores.qs.count()
    context['total_scores'] = total_scores
    context['payment_1h'] = request.user.h100
    context['payment_1r'] = request.user.r100
    context['payment_2h'] = request.user.h200
    context['payment_2r'] = request.user.r200
    context['payment_3h'] = request.user.h300
    context['payment_3r'] = request.user.r300
    context['payment_4h'] = request.user.h400
    return render(request, 'result/undergrad_scores_300.html', context=context)

@login_required
def showUndergradScores100Rain(request):
    context = {}
    filtered_scores = ScoreFilterUndergrad(
        request.GET,
        queryset = Score.objects.filter(~Q(recorded="Y"), undergrad=request.user, semester__semester="Rain", static_level="100")
    )
    context['filtered_scores'] = filtered_scores
    paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
    page_number = request.GET.get('page')
    scores_page_obj = paginated_filtered_scores.get_page(page_number)
    context['scores_page_obj'] = scores_page_obj
    total_scores = filtered_scores.qs.count()
    context['total_scores'] = total_scores
    context['payment'] = request.user.r100
    return render(request, 'result/undergrad_scores_100_rain.html', context=context)


# @login_required
# def showUndergradTranscripts(request):
#     context = {}
#     filtered_scores = ScoreFilterUndergrad(
#         request.GET,
#         queryset = Score.objects.filter(~Q(recorded="Y"), undergrad=request.user, value=1)
#     )
#     context['filtered_scores'] = filtered_scores
#     paginated_filtered_scores = Paginator(filtered_scores.qs, 50)
#     page_number = request.GET.get('page')
#     scores_page_obj = paginated_filtered_scores.get_page(page_number)
#     context['scores_page_obj'] = scores_page_obj
#     total_scores = filtered_scores.qs.count()
#     context['total_scores'] = total_scores
#     return render(request, 'result/undergrad_transripts.html', context=context)

@login_required
def showUndergradResult100Harm(request):
    try:
        score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="100", undergrad=request.user)[0]
        undergrad = score.undergrad
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200

        session = score.session
        scores = Score.objects.all()
        scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="100", undergrad=undergrad).order_by('course__id')

        response_score = []
        response_score_undergrad = []

        for each in scores:
            response_score.append(each)
        for each in scores_undergrad:
            response_score_undergrad.append(each)


        if score.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score = None
        undergrad = request.user
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200
        response_score = []
        response_score_undergrad = []

    try:
        score_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=request.user)[0]
        scores_r = Score.objects.all()
        scores_undergrad_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=undergrad).order_by('course__id')

        response_score_r = []
        response_score_undergrad_r = []

        for each in scores_r:
            response_score_r.append(each)
        for each in scores_undergrad_r:
            response_score_undergrad_r.append(each)

        if score_r.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score_r.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score_r.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score_r.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score_r.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score_r.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score_r = None
        response_score_r = []
        response_score_undergrad_r = []

    return render(request, 'result/undergrad_result_100_harm.html', {'scores':response_score, 'payment_2h':payment_2h,
    'scores_undergrad':response_score_undergrad, 'score': score, 'degree':degree, 'payment_1h':payment_1h, 'payment_1r':payment_1r,
    'scores_r':response_score_r, 'scores_undergrad_r':response_score_undergrad_r, 'score_r': score_r, 'degree':degree})

@login_required
def showUndergradResult200(request):
    try:
        score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="200", undergrad=request.user)[0]
        undergrad = score.undergrad
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200
        payment_2r = score.undergrad.r200
        payment_3h = score.undergrad.h300

        session = score.session
        scores = Score.objects.all()
        scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="200", undergrad=undergrad).order_by('course__id')

        response_score = []
        response_score_undergrad = []

        for each in scores:
            response_score.append(each)
        for each in scores_undergrad:
            response_score_undergrad.append(each)


        if score.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score = None
        undergrad = request.user
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200
        payment_2r = score.undergrad.r200
        payment_3h = score.undergrad.h300

        response_score = []
        response_score_undergrad = []

    try:
        score_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=request.user)[0]
        scores_r = Score.objects.all()
        scores_undergrad_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=undergrad).order_by('course__id')

        response_score_r = []
        response_score_undergrad_r = []

        for each in scores_r:
            response_score_r.append(each)
        for each in scores_undergrad_r:
            response_score_undergrad_r.append(each)

        if score_r.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score_r.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score_r.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score_r.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score_r.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score_r.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score_r = None
        response_score_r = []
        response_score_undergrad_r = []

    return render(request, 'result/undergrad_result_200.html', {'scores':response_score, 'payment_2h':payment_2h, 'payment_2r':payment_2r,
    'scores_undergrad':response_score_undergrad, 'score': score, 'degree':degree, 'payment_1h':payment_1h, 'payment_1r':payment_1r,
    'scores_r':response_score_r, 'scores_undergrad_r':response_score_undergrad_r, 'score_r': score_r, 'degree':degree,
    'payment_3h':payment_3h})

@login_required
def showUndergradResult300(request):
    try:
        score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="300", undergrad=request.user)[0]
        undergrad = score.undergrad
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200
        payment_2r = score.undergrad.r200
        payment_3h = score.undergrad.h300
        payment_3r = score.undergrad.r300
        payment_4h = score.undergrad.h400

        session = score.session
        scores = Score.objects.all()
        scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="300", undergrad=undergrad).order_by('course__id')

        response_score = []
        response_score_undergrad = []

        for each in scores:
            response_score.append(each)
        for each in scores_undergrad:
            response_score_undergrad.append(each)


        if score.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score = None
        undergrad = request.user
        payment_1h = score.undergrad.h100
        payment_1r = score.undergrad.r100
        payment_2h = score.undergrad.h200
        payment_2r = score.undergrad.r200
        payment_3h = score.undergrad.h300
        payment_3r = score.undergrad.r300
        payment_4h = score.undergrad.h400

        response_score = []
        response_score_undergrad = []

    try:
        score_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=request.user)[0]
        scores_r = Score.objects.all()
        scores_undergrad_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=undergrad).order_by('course__id')

        response_score_r = []
        response_score_undergrad_r = []

        for each in scores_r:
            response_score_r.append(each)
        for each in scores_undergrad_r:
            response_score_undergrad_r.append(each)

        if score_r.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score_r.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score_r.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score_r.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score_r.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score_r.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"

    except:
        score_r = None
        response_score_r = []
        response_score_undergrad_r = []

    return render(request, 'result/undergrad_result_300.html', {'scores':response_score, 'payment_2h':payment_2h, 'payment_2r':payment_2r,
    'scores_undergrad':response_score_undergrad, 'score': score, 'degree':degree, 'payment_1h':payment_1h, 'payment_1r':payment_1r,
    'scores_r':response_score_r, 'scores_undergrad_r':response_score_undergrad_r, 'score_r': score_r, 'degree':degree,
    'payment_3h':payment_3h, 'payment_3r':payment_3r, 'payment_4h':payment_4h})

@login_required
def showAdminUndergradResult100Harm(request, id):
    if request.user.type=="A--":
        undergrad = Person.objects.get(id=id)
        try:
            score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="100", undergrad=undergrad)[0]
            session = score.session
            scores = Score.objects.all()
            scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="100", undergrad=undergrad).order_by('course__id')

            response_score = []
            response_score_undergrad = []

            for each in scores:
                response_score.append(each)
            for each in scores_undergrad:
                response_score_undergrad.append(each)

            if score.cumulative_gpa >= 4.50:
                degree = "First Class Honours"
            elif score.cumulative_gpa >= 3.50:
                degree = "Second Class Honours (Upper Division)"
            elif score.cumulative_gpa >= 2.40:
                degree = "Second Class Honours (Lower Division)"
            elif score.cumulative_gpa >= 1.50:
                degree = "Third Class Honours"
            elif score.cumulative_gpa >= 1.00:
                degree = "Pass"
            elif score.cumulative_gpa < 1.00:
                degree = "Fail"
            else:
                degree = "None"

        except:
            score = None
            response_score = []
            response_score_undergrad = []
            degree = None

        try:
            score_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=undergrad)[0]
            scores_r = Score.objects.all()
            scores_undergrad_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=undergrad).order_by('course__id')

            response_score_r = []
            response_score_undergrad_r = []

            for each in scores_r:
                response_score_r.append(each)
            for each in scores_undergrad_r:
                response_score_undergrad_r.append(each)

            if score_r.cumulative_gpa >= 4.50:
                degree = "First Class Honours"
            elif score_r.cumulative_gpa >= 3.50:
                degree = "Second Class Honours (Upper Division)"
            elif score_r.cumulative_gpa >= 2.40:
                degree = "Second Class Honours (Lower Division)"
            elif score_r.cumulative_gpa >= 1.50:
                degree = "Third Class Honours"
            elif score_r.cumulative_gpa >= 1.00:
                degree = "Pass"
            elif score_r.cumulative_gpa < 1.00:
                degree = "Fail"
            else:
                degree = "None"

        except:
            score_r = None
            response_score_r = []
            response_score_undergrad_r = []
            degree = None

        return render(request, 'result/admin_undergrad_result_100_harm.html', {'scores':response_score,
        'scores_undergrad':response_score_undergrad, 'score': score, 'scores_r':response_score_r,
        'scores_undergrad_r':response_score_undergrad_r, 'score_r': score_r, 'degree': degree})
    return redirect('index')



@login_required
def showUndergradResult100Rain(request):
    try:
        score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=request.user)[0]
        undergrad = score.undergrad
        payment = score.undergrad.r100
        session = score.session
        scores = Score.objects.all()
        scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=undergrad).order_by('course__id')
        scores_undergrad2 = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="100", undergrad=undergrad).order_by('-total')

        response_score = []
        response_score_undergrad = []
        courses_list = [""]
        courses_total_list = [0]
        for each in scores:
            response_score.append(each)
        for each in scores_undergrad:
            response_score_undergrad.append(each)

        for each in scores_undergrad2:
            courses_list.append(each.course.course_code)
            courses_total_list.append(each.total)

        if score.cumulative_gpa >= 4.50:
            degree = "First Class Honours"
        elif score.cumulative_gpa >= 3.50:
            degree = "Second Class Honours (Upper Division)"
        elif score.cumulative_gpa >= 2.40:
            degree = "Second Class Honours (Lower Division)"
        elif score.cumulative_gpa >= 1.50:
            degree = "Third Class Honours"
        elif score.cumulative_gpa >= 1.00:
            degree = "Pass"
        elif score.cumulative_gpa < 1.00:
            degree = "Fail"
        else:
            degree = "None"
    except:
        score = None
        undergrad = request.user
        payment = request.user.r100
        response_score = []
        response_score_undergrad = []
        courses_list = [""]
        courses_total_list = [0]

    return render(request, 'result/undergrad_result_100_rain.html', {'scores':response_score,
    'scores_undergrad':response_score_undergrad, 'score': score, 'courses_list':courses_list,
    'courses_total_list':courses_total_list, 'degree':degree, 'payment':payment})

@login_required
def showAdminUndergradResult200(request, id):
    if request.user.type=="A--":
        undergrad = Person.objects.get(id=id)
        try:
            score = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="200", undergrad=undergrad)[0]
            session = score.session
            scores = Score.objects.all()
            scores_undergrad = Score.objects.filter(~Q(recorded="Y"), semester__semester="Harmattan", static_level="200", undergrad=undergrad).order_by('course__id')

            response_score = []
            response_score_undergrad = []

            for each in scores:
                response_score.append(each)
            for each in scores_undergrad:
                response_score_undergrad.append(each)

            if score.cumulative_gpa >= 4.50:
                degree = "First Class Honours"
            elif score.cumulative_gpa >= 3.50:
                degree = "Second Class Honours (Upper Division)"
            elif score.cumulative_gpa >= 2.40:
                degree = "Second Class Honours (Lower Division)"
            elif score.cumulative_gpa >= 1.50:
                degree = "Third Class Honours"
            elif score.cumulative_gpa >= 1.00:
                degree = "Pass"
            elif score.cumulative_gpa < 1.00:
                degree = "Fail"
            else:
                degree = "None"

        except:
            score = None
            response_score = []
            response_score_undergrad = []
            degree = None

        try:
            score_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=undergrad)[0]
            scores_r = Score.objects.all()
            scores_undergrad_r = Score.objects.filter(~Q(recorded="Y"), semester__semester="Rain", static_level="200", undergrad=undergrad).order_by('course__id')

            response_score_r = []
            response_score_undergrad_r = []

            for each in scores_r:
                response_score_r.append(each)
            for each in scores_undergrad_r:
                response_score_undergrad_r.append(each)

            if score_r.cumulative_gpa >= 4.50:
                degree = "First Class Honours"
            elif score_r.cumulative_gpa >= 3.50:
                degree = "Second Class Honours (Upper Division)"
            elif score_r.cumulative_gpa >= 2.40:
                degree = "Second Class Honours (Lower Division)"
            elif score_r.cumulative_gpa >= 1.50:
                degree = "Third Class Honours"
            elif score_r.cumulative_gpa >= 1.00:
                degree = "Pass"
            elif score_r.cumulative_gpa < 1.00:
                degree = "Fail"
            else:
                degree = "None"

        except:
            score_r = None
            response_score_r = []
            response_score_undergrad_r = []
            degree = None

        return render(request, 'result/admin_undergrad_result_200.html', {'scores':response_score,
        'scores_undergrad':response_score_undergrad, 'score': score, 'scores_r':response_score_r,
        'scores_undergrad_r':response_score_undergrad_r, 'score_r': score_r, 'degree': degree})
    return redirect('index')

@login_required
def showAdminSpreadsheet(request, id):
    if request.user.type=="A--":
        spreadsheet = Spreadsheet.objects.get(id=id)
        programme = spreadsheet.programme
        level = spreadsheet.level
        semester = spreadsheet.semester
        session = spreadsheet.session
        session_created = spreadsheet.session.created
        semester_created = spreadsheet.semester.created

        programme_students = Person.objects.filter(programme=programme)
        scores = Score.objects.filter(session=session, semester=semester, static_level=str(level.level)).order_by('course__course_code')

        cumulative_scores = Score.objects.filter(~Q(recorded="Y"), session__created__lte=session_created, semester__created__lte=semester_created)

        response_scores_undergrad = []
        cumulative_response_scores_undergrad = []

        selected_courses = []
        for each in scores:
            if each.undergrad in programme_students:
                response_scores_undergrad.append(each)
                if each.course not in selected_courses:
                    selected_courses.append(each.course)

        for each in cumulative_scores:
            if each.undergrad in programme_students:
                cumulative_response_scores_undergrad.append(each)

        filtered_studs = []
        for each in response_scores_undergrad:
            if each.undergrad.username not in filtered_studs:
                filtered_studs.append(each.undergrad.username)
        filtered_studs.sort()

        tu_dict = {}
        studs = 0
        for each in response_scores_undergrad:
            if each.undergrad not in tu_dict and each.total != None:
                tu_dict[each.undergrad] = each.semester_credits
                studs += 1
            else:
                pass

        ctu_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctu_dict:
                ctu_dict[each.undergrad] = each.credit_unit
            else:
                ctu_dict[each.undergrad] += each.credit_unit

        tu2_dict = {}
        for each in ctu_dict:
            for each2 in tu_dict:
                if each == each2:
                    tu2_dict[each] = ctu_dict[each] - tu_dict[each2]

        tgp_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in tgp_dict and each.total != None:
                tgp_dict[each.undergrad] = each.semester_points
            else:
                pass

        ctgp_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctgp_dict:
                ctgp_dict[each.undergrad] = each.points
            else:
                ctgp_dict[each.undergrad] += each.points

        tgp2_dict = {}
        for each in ctgp_dict:
            for each2 in tgp_dict:
                if each == each2:
                    tgp2_dict[each] = ctgp_dict[each] - tgp_dict[each2]

        gpa_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in gpa_dict and each.total != None:
                gpa_dict[each.undergrad] = each.semester_gpa
            else:
                pass

        cgpa_dict = {}
        # below1 = 0
        # above1 = 0
        for each in ctgp_dict:
            for each2 in ctu_dict:
                if each == each2:
                    if ctu_dict[each2] == 0:
                        cgpa_dict[each] = 0
                    else:
                        cgpa_dict[each] = ctgp_dict[each] / ctu_dict[each2]

            # if cgpa_dict[each] >= 1.50:
            #     above1 += 1
            # elif cgpa_dict[each] < 1.50:
            #     below1 += 1

        gpa2_dict = {}
        for each in tgp2_dict:
            for each2 in tu2_dict:
                if each == each2:
                    try:
                        gpa2_dict[each] = tgp2_dict[each] / tu2_dict[each2]
                    except:
                        gpa2_dict[each] = "0.00"

        academic_dict = {}
        below1_twice = 0
        below1 = 0
        above1 = 0
        for item,value in gpa2_dict.items():
            for item2,value2 in cgpa_dict.items():
                if item == item2:
                    try:
                        if value < 1.5 and value2 < 1.5:
                            academic_dict[item2] = "ADVISED TO WITHDRAW"
                            below1_twice += 1
                        elif value >= 1.5 and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value >= 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                        elif value < 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                    except:
                        if value == "0.00" and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value == "0.00" and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
        outstanding_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None or each.total < 45:
                    if each.undergrad not in outstanding_courses:
                        outstanding_courses[each.undergrad] = []
                        outstanding_courses[each.undergrad].append(each.course)
                    elif each.undergrad in outstanding_courses:
                        outstanding_courses[each.undergrad].append(each.course)

        passed_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None:
                    pass
                else:
                    if each.total >= 45:
                        if each.undergrad not in passed_courses:
                            passed_courses[each.undergrad] = []
                            passed_courses[each.undergrad].append(each.course)
                        elif each.undergrad in passed_courses:
                            passed_courses[each.undergrad].append(each.course)

        outstanding = {}
        for item2,value2 in passed_courses.items():
            for item,value in outstanding_courses.items():
                if item == item2:
                    outstanding[item] = []
                    outstanding_list = [each for each in value if each not in value2]
                    outstanding[item] = outstanding_list

        return render(request, 'result/admin_spreadsheet.html', {'programme_students':programme_students, 'response_scores_undergrad':response_scores_undergrad,
        'selected_courses':selected_courses, 'programme':programme, 'tu_dict':tu_dict, 'tgp_dict':tgp_dict, 'gpa_dict':gpa_dict, 'studs':studs, 'outstanding':outstanding,
        'tu2_dict':tu2_dict, 'tgp2_dict':tgp2_dict, 'gpa2_dict':gpa2_dict, 'ctu_dict':ctu_dict, 'ctgp_dict':ctgp_dict, 'cgpa_dict':cgpa_dict, 'academic_dict':academic_dict,
        'above1':above1, 'below1':below1, 'filtered_studs':filtered_studs, 'scores':scores, 'level':level, 'semester':semester, 'session':session, 'below1_twice':below1_twice,
        'cumulative_response_scores_undergrad':cumulative_response_scores_undergrad})
    return redirect('index')

@login_required
def showSpreadsheetHoD(request, id):
    if request.user.type=="HoD":
        spreadsheet = Spreadsheet.objects.get(id=id)
        programme = spreadsheet.programme
        level = spreadsheet.level
        semester = spreadsheet.semester
        session = spreadsheet.session
        session_created = spreadsheet.session.created
        semester_created = spreadsheet.semester.created

        programme_students = Person.objects.filter(programme=programme)
        scores = Score.objects.filter(session=session, semester=semester, static_level=str(level.level)).order_by('course__course_code')

        cumulative_scores = Score.objects.filter(~Q(recorded="Y"), session__created__lte=session_created, semester__created__lte=semester_created)

        response_scores_undergrad = []
        cumulative_response_scores_undergrad = []

        selected_courses = []
        for each in scores:
            if each.undergrad in programme_students:
                response_scores_undergrad.append(each)
                if each.course not in selected_courses:
                    selected_courses.append(each.course)

        for each in cumulative_scores:
            if each.undergrad in programme_students:
                cumulative_response_scores_undergrad.append(each)

        filtered_studs = []
        for each in response_scores_undergrad:
            if each.undergrad.username not in filtered_studs:
                filtered_studs.append(each.undergrad.username)
        filtered_studs.sort()

        tu_dict = {}
        studs = 0
        for each in response_scores_undergrad:
            if each.undergrad not in tu_dict and each.total != None:
                tu_dict[each.undergrad] = each.semester_credits
                studs += 1
            else:
                pass

        ctu_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctu_dict:
                ctu_dict[each.undergrad] = each.credit_unit
            else:
                ctu_dict[each.undergrad] += each.credit_unit

        tu2_dict = {}
        for each in ctu_dict:
            for each2 in tu_dict:
                if each == each2:
                    tu2_dict[each] = ctu_dict[each] - tu_dict[each2]

        tgp_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in tgp_dict and each.total != None:
                tgp_dict[each.undergrad] = each.semester_points
            else:
                pass

        ctgp_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctgp_dict:
                ctgp_dict[each.undergrad] = each.points
            else:
                ctgp_dict[each.undergrad] += each.points

        tgp2_dict = {}
        for each in ctgp_dict:
            for each2 in tgp_dict:
                if each == each2:
                    tgp2_dict[each] = ctgp_dict[each] - tgp_dict[each2]

        gpa_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in gpa_dict and each.total != None:
                gpa_dict[each.undergrad] = each.semester_gpa
            else:
                pass

        cgpa_dict = {}
        # below1 = 0
        # above1 = 0
        for each in ctgp_dict:
            for each2 in ctu_dict:
                if each == each2:
                    if ctu_dict[each2] == 0:
                        cgpa_dict[each] = 0
                    else:
                        cgpa_dict[each] = ctgp_dict[each] / ctu_dict[each2]


            # if cgpa_dict[each] >= 1.50:
            #     above1 += 1
            # elif cgpa_dict[each] < 1.50:
            #     below1 += 1

        gpa2_dict = {}
        for each in tgp2_dict:
            for each2 in tu2_dict:
                if each == each2:
                    try:
                        gpa2_dict[each] = tgp2_dict[each] / tu2_dict[each2]
                    except:
                        gpa2_dict[each] = "0.00"

        academic_dict = {}
        below1_twice = 0
        below1 = 0
        above1 = 0
        for item,value in gpa2_dict.items():
            for item2,value2 in cgpa_dict.items():
                if item == item2:
                    try:
                        if value < 1.5 and value2 < 1.5:
                            academic_dict[item2] = "ADVISED TO WITHDRAW"
                            below1_twice += 1
                        elif value >= 1.5 and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value >= 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                        elif value < 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                    except:
                        if value == "0.00" and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value == "0.00" and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
        outstanding_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None or each.total < 45:
                    if each.undergrad not in outstanding_courses:
                        outstanding_courses[each.undergrad] = []
                        outstanding_courses[each.undergrad].append(each.course)
                    elif each.undergrad in outstanding_courses:
                        outstanding_courses[each.undergrad].append(each.course)

        passed_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None:
                    pass
                else:
                    if each.total >= 45:
                        if each.undergrad not in passed_courses:
                            passed_courses[each.undergrad] = []
                            passed_courses[each.undergrad].append(each.course)
                        elif each.undergrad in passed_courses:
                            passed_courses[each.undergrad].append(each.course)

        outstanding = {}
        for item2,value2 in passed_courses.items():
            for item,value in outstanding_courses.items():
                if item == item2:
                    outstanding[item] = []
                    outstanding_list = [each for each in value if each not in value2]
                    outstanding[item] = outstanding_list

        return render(request, 'result/hod_spreadsheet.html', {'programme_students':programme_students, 'response_scores_undergrad':response_scores_undergrad,
        'selected_courses':selected_courses, 'programme':programme, 'tu_dict':tu_dict, 'tgp_dict':tgp_dict, 'gpa_dict':gpa_dict, 'studs':studs, 'outstanding':outstanding,
        'tu2_dict':tu2_dict, 'tgp2_dict':tgp2_dict, 'gpa2_dict':gpa2_dict, 'ctu_dict':ctu_dict, 'ctgp_dict':ctgp_dict, 'cgpa_dict':cgpa_dict, 'academic_dict':academic_dict,
        'above1':above1, 'below1':below1, 'filtered_studs':filtered_studs, 'scores':scores, 'level':level, 'semester':semester, 'session':session, 'below1_twice':below1_twice,
        'cumulative_response_scores_undergrad':cumulative_response_scores_undergrad})
    return redirect('index')

@login_required
def showSpreadsheetDean(request, id):
    if request.user.type=="Dean":
        spreadsheet = Spreadsheet.objects.get(id=id)
        programme = spreadsheet.programme
        level = spreadsheet.level
        semester = spreadsheet.semester
        session = spreadsheet.session
        session_created = spreadsheet.session.created
        semester_created = spreadsheet.semester.created

        programme_students = Person.objects.filter(programme=programme)
        scores = Score.objects.filter(session=session, semester=semester, static_level=str(level.level)).order_by('course__course_code')

        cumulative_scores = Score.objects.filter(~Q(recorded="Y"), session__created__lte=session_created, semester__created__lte=semester_created)

        response_scores_undergrad = []
        cumulative_response_scores_undergrad = []

        selected_courses = []
        for each in scores:
            if each.undergrad in programme_students:
                response_scores_undergrad.append(each)
                if each.course not in selected_courses:
                    selected_courses.append(each.course)

        for each in cumulative_scores:
            if each.undergrad in programme_students:
                cumulative_response_scores_undergrad.append(each)

        filtered_studs = []
        for each in response_scores_undergrad:
            if each.undergrad.username not in filtered_studs:
                filtered_studs.append(each.undergrad.username)
        filtered_studs.sort()

        tu_dict = {}
        studs = 0
        for each in response_scores_undergrad:
            if each.undergrad not in tu_dict and each.total != None:
                tu_dict[each.undergrad] = each.semester_credits
                studs += 1
            else:
                pass

        ctu_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctu_dict:
                ctu_dict[each.undergrad] = each.credit_unit
            else:
                ctu_dict[each.undergrad] += each.credit_unit

        tu2_dict = {}
        for each in ctu_dict:
            for each2 in tu_dict:
                if each == each2:
                    tu2_dict[each] = ctu_dict[each] - tu_dict[each2]

        tgp_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in tgp_dict and each.total != None:
                tgp_dict[each.undergrad] = each.semester_points
            else:
                pass

        ctgp_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctgp_dict:
                ctgp_dict[each.undergrad] = each.points
            else:
                ctgp_dict[each.undergrad] += each.points

        tgp2_dict = {}
        for each in ctgp_dict:
            for each2 in tgp_dict:
                if each == each2:
                    tgp2_dict[each] = ctgp_dict[each] - tgp_dict[each2]

        gpa_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in gpa_dict and each.total != None:
                gpa_dict[each.undergrad] = each.semester_gpa
            else:
                pass

        cgpa_dict = {}
        # below1 = 0
        # above1 = 0
        for each in ctgp_dict:
            for each2 in ctu_dict:
                if each == each2:
                    if ctu_dict[each2] == 0:
                        cgpa_dict[each] = 0
                    else:
                        cgpa_dict[each] = ctgp_dict[each] / ctu_dict[each2]

            # if cgpa_dict[each] >= 1.50:
            #     above1 += 1
            # elif cgpa_dict[each] < 1.50:
            #     below1 += 1

        gpa2_dict = {}
        for each in tgp2_dict:
            for each2 in tu2_dict:
                if each == each2:
                    try:
                        gpa2_dict[each] = tgp2_dict[each] / tu2_dict[each2]
                    except:
                        gpa2_dict[each] = "0.00"

        academic_dict = {}
        below1_twice = 0
        below1 = 0
        above1 = 0
        for item,value in gpa2_dict.items():
            for item2,value2 in cgpa_dict.items():
                if item == item2:
                    try:
                        if value < 1.5 and value2 < 1.5:
                            academic_dict[item2] = "ADVISED TO WITHDRAW"
                            below1_twice += 1
                        elif value >= 1.5 and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value >= 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                        elif value < 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                    except:
                        if value == "0.00" and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value == "0.00" and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
        outstanding_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None or each.total < 45:
                    if each.undergrad not in outstanding_courses:
                        outstanding_courses[each.undergrad] = []
                        outstanding_courses[each.undergrad].append(each.course)
                    elif each.undergrad in outstanding_courses:
                        outstanding_courses[each.undergrad].append(each.course)

        passed_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None:
                    pass
                else:
                    if each.total >= 45:
                        if each.undergrad not in passed_courses:
                            passed_courses[each.undergrad] = []
                            passed_courses[each.undergrad].append(each.course)
                        elif each.undergrad in passed_courses:
                            passed_courses[each.undergrad].append(each.course)

        outstanding = {}
        for item2,value2 in passed_courses.items():
            for item,value in outstanding_courses.items():
                if item == item2:
                    outstanding[item] = []
                    outstanding_list = [each for each in value if each not in value2]
                    outstanding[item] = outstanding_list

        return render(request, 'result/dean_spreadsheet.html', {'programme_students':programme_students, 'response_scores_undergrad':response_scores_undergrad,
        'selected_courses':selected_courses, 'programme':programme, 'tu_dict':tu_dict, 'tgp_dict':tgp_dict, 'gpa_dict':gpa_dict, 'studs':studs, 'outstanding':outstanding,
        'tu2_dict':tu2_dict, 'tgp2_dict':tgp2_dict, 'gpa2_dict':gpa2_dict, 'ctu_dict':ctu_dict, 'ctgp_dict':ctgp_dict, 'cgpa_dict':cgpa_dict, 'academic_dict':academic_dict,
        'above1':above1, 'below1':below1, 'filtered_studs':filtered_studs, 'scores':scores, 'level':level, 'semester':semester, 'session':session, 'below1_twice':below1_twice,
        'cumulative_response_scores_undergrad':cumulative_response_scores_undergrad})
    return redirect('index')

@login_required
def showSpreadsheetVC(request, id):
    if request.user.type=="VC":
        spreadsheet = Spreadsheet.objects.get(id=id)
        programme = spreadsheet.programme
        level = spreadsheet.level
        semester = spreadsheet.semester
        session = spreadsheet.session
        session_created = spreadsheet.session.created
        semester_created = spreadsheet.semester.created

        programme_students = Person.objects.filter(programme=programme)
        scores = Score.objects.filter(session=session, semester=semester, static_level=str(level.level)).order_by('course__course_code')

        cumulative_scores = Score.objects.filter(~Q(recorded="Y"), session__created__lte=session_created, semester__created__lte=semester_created)

        response_scores_undergrad = []
        cumulative_response_scores_undergrad = []

        selected_courses = []
        for each in scores:
            if each.undergrad in programme_students:
                response_scores_undergrad.append(each)
                if each.course not in selected_courses:
                    selected_courses.append(each.course)

        for each in cumulative_scores:
            if each.undergrad in programme_students:
                cumulative_response_scores_undergrad.append(each)

        filtered_studs = []
        for each in response_scores_undergrad:
            if each.undergrad.username not in filtered_studs:
                filtered_studs.append(each.undergrad.username)
        filtered_studs.sort()

        tu_dict = {}
        studs = 0
        for each in response_scores_undergrad:
            if each.undergrad not in tu_dict and each.total != None:
                tu_dict[each.undergrad] = each.semester_credits
                studs += 1
            else:
                pass

        ctu_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctu_dict:
                ctu_dict[each.undergrad] = each.credit_unit
            else:
                ctu_dict[each.undergrad] += each.credit_unit

        tu2_dict = {}
        for each in ctu_dict:
            for each2 in tu_dict:
                if each == each2:
                    tu2_dict[each] = ctu_dict[each] - tu_dict[each2]

        tgp_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in tgp_dict and each.total != None:
                tgp_dict[each.undergrad] = each.semester_points
            else:
                pass

        ctgp_dict = {}
        for each in cumulative_response_scores_undergrad:
            if each.undergrad not in ctgp_dict:
                ctgp_dict[each.undergrad] = each.points
            else:
                ctgp_dict[each.undergrad] += each.points

        tgp2_dict = {}
        for each in ctgp_dict:
            for each2 in tgp_dict:
                if each == each2:
                    tgp2_dict[each] = ctgp_dict[each] - tgp_dict[each2]

        gpa_dict = {}
        for each in response_scores_undergrad:
            if each.undergrad not in gpa_dict and each.total != None:
                gpa_dict[each.undergrad] = each.semester_gpa
            else:
                pass

        cgpa_dict = {}
        # below1 = 0
        # above1 = 0
        for each in ctgp_dict:
            for each2 in ctu_dict:
                if each == each2:
                    if ctu_dict[each2] == 0:
                        cgpa_dict[each] = 0
                    else:
                        cgpa_dict[each] = ctgp_dict[each] / ctu_dict[each2]

            # if cgpa_dict[each] >= 1.50:
            #     above1 += 1
            # elif cgpa_dict[each] < 1.50:
            #     below1 += 1

        gpa2_dict = {}
        for each in tgp2_dict:
            for each2 in tu2_dict:
                if each == each2:
                    try:
                        gpa2_dict[each] = tgp2_dict[each] / tu2_dict[each2]
                    except:
                        gpa2_dict[each] = "0.00"

        academic_dict = {}
        below1_twice = 0
        below1 = 0
        above1 = 0
        for item,value in gpa2_dict.items():
            for item2,value2 in cgpa_dict.items():
                if item == item2:
                    try:
                        if value < 1.5 and value2 < 1.5:
                            academic_dict[item2] = "ADVISED TO WITHDRAW"
                            below1_twice += 1
                        elif value >= 1.5 and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value >= 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                        elif value < 1.5 and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
                    except:
                        if value == "0.00" and value2 < 1.5:
                            academic_dict[item2] = "PROBATION"
                            below1 += 1
                        elif value == "0.00" and value2 >= 1.5:
                            academic_dict[item2] = "GOOD STANDING"
                            above1 += 1
        outstanding_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None or each.total < 45:
                    if each.undergrad not in outstanding_courses:
                        outstanding_courses[each.undergrad] = []
                        outstanding_courses[each.undergrad].append(each.course)
                    elif each.undergrad in outstanding_courses:
                        outstanding_courses[each.undergrad].append(each.course)

        passed_courses = {}
        for each in cumulative_scores:
            if each.undergrad in programme_students:
                if each.total == None:
                    pass
                else:
                    if each.total >= 45:
                        if each.undergrad not in passed_courses:
                            passed_courses[each.undergrad] = []
                            passed_courses[each.undergrad].append(each.course)
                        elif each.undergrad in passed_courses:
                            passed_courses[each.undergrad].append(each.course)

        outstanding = {}
        for item2,value2 in passed_courses.items():
            for item,value in outstanding_courses.items():
                if item == item2:
                    outstanding[item] = []
                    outstanding_list = [each for each in value if each not in value2]
                    outstanding[item] = outstanding_list

        return render(request, 'result/vc_spreadsheet.html', {'programme_students':programme_students, 'response_scores_undergrad':response_scores_undergrad,
        'selected_courses':selected_courses, 'programme':programme, 'tu_dict':tu_dict, 'tgp_dict':tgp_dict, 'gpa_dict':gpa_dict, 'studs':studs, 'outstanding':outstanding,
        'tu2_dict':tu2_dict, 'tgp2_dict':tgp2_dict, 'gpa2_dict':gpa2_dict, 'ctu_dict':ctu_dict, 'ctgp_dict':ctgp_dict, 'cgpa_dict':cgpa_dict, 'academic_dict':academic_dict,
        'above1':above1, 'below1':below1, 'filtered_studs':filtered_studs, 'scores':scores, 'level':level, 'semester':semester, 'session':session, 'below1_twice':below1_twice,
        'cumulative_response_scores_undergrad':cumulative_response_scores_undergrad})
    return redirect('index')
